@@ -16,20 +16,20 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ErrorViewerConsoleListener.cpp,v 1.8.2.1 2004/11/15 15:08:50 chpe Exp $
+ *  $Id: ErrorViewerConsoleListener.cpp,v 1.11.2.4 2005/04/26 12:04:02 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
+#include "mozilla-config.h"
+
 #include "config.h"
-#endif
 
 #include "error-viewer.h"
 
 #include "ErrorViewerConsoleListener.h"
 
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsCOMPtr.h>
 #include <nsMemory.h>
 
@@ -49,44 +49,63 @@ ErrorViewerConsoleListener::ErrorViewerConsoleListener()
 
 ErrorViewerConsoleListener::~ErrorViewerConsoleListener()
 {
-	LOG ("ErrorViewerConsoleListener dtor %p", this)
+	LOG ("ErrorViewerConsoleListener dtor %p", this);
 }
 
 nsresult
 ErrorViewerConsoleListener::GetMessageFromError (nsIScriptError *aError,
 						 char **aMessage)
 {
+	NS_ENSURE_ARG (aError);
 	NS_ENSURE_ARG_POINTER (aMessage);
 
 	nsresult rv;
-	PRUnichar *message = nsnull;
-	rv = aError->GetMessage (&message);
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && message, NS_ERROR_FAILURE);
-
 	char *category = nsnull;
 	rv = aError->GetCategory (&category);
 	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && category, NS_ERROR_FAILURE);
 
-	/*
-	 * No docs on category, but some are listed in:
-	 * http://lxr.mozilla.org/seamonkey/source/dom/src/base/nsJSEnvironment.cpp#208
-	 *
-	 * XUL javascript
-	 * content javascript
-	 * component javascript
-	 *
-	 * Some errors are none of the above. GNOME Bugzilla #134438
-	 */
-	if (strstr (category, "javascript") == NULL)
-	{
-		nsEmbedCString cMessage;
-		NS_UTF16ToCString (nsEmbedString (message),
-				   NS_CSTRING_ENCODING_UTF8, cMessage);
+	nsEmbedString message;
+#ifdef HAVE_GECKO_1_8
+	rv = aError->GetErrorMessage (message);
+#else
+	PRUnichar *msg = nsnull;
+	rv = aError->GetMessage (&msg);
+	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && msg, NS_ERROR_FAILURE);
+	message.Assign (msg);
+	nsMemory::Free (msg);
+#endif
+	NS_ENSURE_SUCCESS (rv, rv);
 
+	nsEmbedCString cMessage;
+	NS_UTF16ToCString (nsEmbedString (message),
+				NS_CSTRING_ENCODING_UTF8, cMessage);
+
+	/*
+	 * FIXME: file bug to document all of these in
+	 * http://lxr.mozilla.org/seamonkey/source/js/src/xpconnect/idl/nsIScriptError.idl
+	 *
+	 * With line and/or col # info:
+	 * "xbl javascript" (nsXBLDocumentInfo.cpp:)
+	 * "chrome javascript" and "content javascript" (nsJSEnvironment.cpp)
+	 * "CSS Parser" (nsCSSScanner.cpp)
+	 * "DOM::HTML" (nsDOMClassInfo.cpp: line # only)
+	 * "XBL Content Sink" (nsXBLContentSink.cpp: line # only)
+	 *
+	 * Without line and col # info:
+	 * "HTML" (nsFormSubmission.cpp)
+	 * "XUL Document" (nsXULDocument.cpp)
+	 * "ImageMap" (nsImageMap.cpp: has source line info)
+	 * "CSS Loader" (nsCSSLoader.cpp)
+	 */
+	/* FIXME FIXME FIXME */
+	if (strstr (category, "javascript") == NULL &&
+	    strcmp (category, "CSS Parser") != 0 &&
+	    strcmp (category, "DOM::HTML") != 0 &&
+	    strcmp (category, "XBL Content Sink") != 0)
+	{
 		/* Don't bother looking for source lines -- they're not there */
 		*aMessage = g_strdup_printf (_("Error:\n%s"), cMessage.get());
 
-		nsMemory::Free (message);
 		nsMemory::Free (category);
 
 		return NS_OK;
@@ -96,24 +115,28 @@ ErrorViewerConsoleListener::GetMessageFromError (nsIScriptError *aError,
 	rv = aError->GetLineNumber (&lineNumber);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
+#ifdef HAVE_GECKO_1_8
+	nsEmbedString sourceName;
+	rv = aError->GetSourceName (sourceName);
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	nsEmbedCString cSourceName;
+	NS_UTF16ToCString (sourceName, NS_CSTRING_ENCODING_UTF8, cSourceName);
+#else
 	PRUnichar *sourceName = nsnull;
 	rv = aError->GetSourceName (&sourceName);
 	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && sourceName, NS_ERROR_FAILURE);
 
-	nsEmbedCString cMessage;
-	NS_UTF16ToCString (nsEmbedString (message),
-			   NS_CSTRING_ENCODING_UTF8, cMessage);
-
 	nsEmbedCString cSourceName;
 	NS_UTF16ToCString (nsEmbedString (sourceName),
 			   NS_CSTRING_ENCODING_UTF8, cSourceName);
+	nsMemory::Free (sourceName);
+#endif
 
 	*aMessage = g_strdup_printf (
 			_("Javascript error in %s on line %d:\n%s"),
 			cSourceName.get(), lineNumber, cMessage.get());
 
-	nsMemory::Free (message);
-	nsMemory::Free (sourceName);
 	nsMemory::Free (category);
 
 	return NS_OK;
