@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-sidebar-embed.c,v 1.6 2005/01/23 23:12:11 chpe Exp $
+ * $Id: ephy-sidebar-embed.c,v 1.8.2.2 2005/04/19 10:03:41 chpe Exp $
  */
 
 #include "config.h"
@@ -142,7 +142,7 @@ popup_menu_at_coords (GtkMenu *menu,
 {
 	EphyEmbedEvent *event = (EphyEmbedEvent *) user_data;
 
-	ephy_embed_event_get_coords (event, x, y);
+	ephy_embed_event_get_coords (event, (guint*) x, (guint*) y);
 
 	*push_in = TRUE;
 }
@@ -186,7 +186,7 @@ show_context_menu (EphySidebarEmbed *sbembed,
 
 	context = ephy_embed_event_get_context (event);
 
-	LOG ("show_embed_popup context %x", context)
+	LOG ("show_embed_popup context %x", context);
 
 	if ((context & EPHY_EMBED_CONTEXT_EMAIL_LINK) &&
 	    (context & EPHY_EMBED_CONTEXT_IMAGE))
@@ -226,9 +226,9 @@ show_context_menu (EphySidebarEmbed *sbembed,
 	g_object_set (action, "sensitive", has_background,
 			      "visible", has_background, NULL);
 	action = gtk_ui_manager_get_action (manager, "/EphyLinkPopup/OpenLinkInNewWindowLP");
-	g_object_set (action, "sensitive", can_open_in_new, FALSE);
+	g_object_set (action, "sensitive", can_open_in_new, NULL);
 	action = gtk_ui_manager_get_action (manager, "/EphyLinkPopup/OpenLinkInNewTabLP");
-	g_object_set (action, "sensitive", can_open_in_new, FALSE);
+	g_object_set (action, "sensitive", can_open_in_new, NULL);
 
 	can_copy = ephy_command_manager_can_do_command (EPHY_COMMAND_MANAGER (embed), "cmd_copy");
 	can_cut = ephy_command_manager_can_do_command (EPHY_COMMAND_MANAGER (embed), "cmd_cut");
@@ -322,7 +322,7 @@ embed_mouse_click_cb (EphyEmbed *embed,
 	modifier = ephy_embed_event_get_modifier (event);
 
 	LOG ("ephy_sidebar_mouse_click_cb: type %d, context %x, modifier %x",
-	     button, context, modifier)
+	     button, context, modifier);
 
 	with_control = (modifier & GDK_CONTROL_MASK) != 0;
 	with_shift = (modifier & GDK_SHIFT_MASK) != 0;
@@ -386,25 +386,6 @@ embed_mouse_click_cb (EphyEmbed *embed,
 	return handled;
 }
 
-static void 
-embed_new_window_cb (EphyEmbed *embed,
-		     EphyEmbed **new_embed,
-		     EphyEmbedChrome chromemask,
-		     gpointer data)
-{
-	EphyWindow *window;
-	EphyTab *new_tab;
-
-	window = ephy_window_new_with_chrome (chromemask);
-
-	new_tab = ephy_tab_new ();
-	gtk_widget_show (GTK_WIDGET (new_tab));
-
-	ephy_window_add_tab (window, new_tab, -1, FALSE);
-
-	*new_embed = ephy_tab_get_embed (new_tab);
-}
-
 static void
 ephy_sidebar_embed_create_embed (EphySidebarEmbed *sbembed)
 {
@@ -423,10 +404,6 @@ ephy_sidebar_embed_create_embed (EphySidebarEmbed *sbembed)
 	{
 		ephy_embed_load_url (embed, sbembed->priv->url);
 
-		g_signal_connect (G_OBJECT (embed),
-				  "ge_new_window",
-				  G_CALLBACK(embed_new_window_cb),
-				  NULL);
 		g_signal_connect (G_OBJECT (embed),
 				  "ge_dom_mouse_click",
 				  G_CALLBACK(embed_mouse_click_cb),
